<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Perincian</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Teka</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Temui</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Biasa</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Besar</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Terlepas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Berjaya</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Permainan Tamat</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 dari %n mata</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 dari %n mata</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 dari %n mata</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 dari %n mata</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 dari %n mata</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n mata</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Skor maksimum telah dikira dari tiga pilih perkataan berikut:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n tekaan</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n percubaan</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Klasik</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Isian Semua</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Stamina</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Strikeout</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Pengumpukan</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Disiplin</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Kiraan mengundur bermula dari 30 saat dan meningkat jika tekaan betul</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Kiraan mengundur bermula dari 3 minit.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Kiraan mengundur bermula dari 30 saat dan diisi semula jika tekaan betul.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Kiraan mengundur bermula dari 45 saat dan dijeda jika tekaan betul.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Permainan tamat selepas 3 tekaan salah.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Permainan tamat selepas 30 tekaan.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Kiraan mengundur bermula dari 30 saat dan meningkat atau menurun mengikut tekaan.</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Tidak boleh baca dadu dari fail.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Tidak boleh baca senarai perkataan dari fail.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Bahasa Papan</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Suai</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Pilih...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Perhatian:&lt;/b&gt; Tetapan ini akan berkesan bila anda mulakan permainan baru.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Bahasa:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Dadu:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Senarai perkataan:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Kamus:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Pilih Fail Dadu</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Pilih Fail Senarai Perkataan</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pilih bahasa aplikasi:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Bahasa Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Sila mulakan semula aplikasi ini supaya perubahan bahasa berkesan.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Permainan Baru</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Amaun Perkataan:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Panjangan Perkataan Minimum:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Rendah</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Sederhana</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Tinggi</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Rawak</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n abjad</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Skor Tertinggi</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Tarikh</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Dijeda&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Klik untuk sambung semula permainan.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Tunggu sebentar&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Memuatkan permainan...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Klik untuk mulakan permainan baru.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Tunggu sebentar&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Menjana papan baru...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Tunggu sebentar&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Mengoptimumkan senarai perkataan...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Permainan</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>&amp;Permainan Baru...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>Lempar &amp;Baru</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>P&amp;ilih...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Kongsi...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Tamat</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Jeda</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>Perin&amp;cian</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>Skor &amp;Tertinggi</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Keluar</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>T&amp;etapan</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Tunjuk Skor &amp;Maksimum</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>Jan&amp;gan Sesekali</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Tamatkan Permainan</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Sentiasa</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Tunjuk Pe&amp;rkataan Terlepas</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Tunjuk K&amp;iraan Perkataan</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>Bahasa &amp;Papan...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Bahasa Aplikasi...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ba&amp;ntuan</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>Ka&amp;walan</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Perih&amp;al</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Perihal &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Hakcipta &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Perihal</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Varian seorang pemain bagi permainan &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Dikeluarkan dibawah lesen &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Senarai perkataan Bahasa Inggeris berasaskan pada &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; oleh Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Senarai perkataan Bahasa Ibrani berasaskan pada &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; oleh Nadav Har&apos;El dan Dan Kenigsberg</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Import Permainan</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Permaina Tanglet (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Tidak boleh mulakan permainan yang diminta.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Eksport Permainan</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soalan</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Tamatkan permainan semasa?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Perincian</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Saiz Papan:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Biasa</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Besar</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Kepadatan Perkataan:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Panjang Perkataan:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 atau lebih abjad</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Jenis Permainan:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Keterangan:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kawalan</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Main Menggunakan Tetikus:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Pilih perkataan:&lt;/b&gt; Klik pada abjad perkataan.&lt;br&gt;&lt;b&gt;Buat tekaan:&lt;/b&gt; Klik pada abjad terpilih yang terakhir.&lt;br&gt;&lt;b&gt;Padam abjad:&lt;/b&gt; Klik pada abjad terpilih yang awal.&lt;br&gt;&lt;b&gt;Kosongkan perkataan:&lt;/b&gt; Klik dua kali pada abjad terpilih yang pertama.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Main Menggunakan Papan Kekunci:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Pilih perkataan:&lt;/b&gt; Taip abjad perkataan tersebut.&lt;br&gt;&lt;b&gt;Buat tekaan:&lt;/b&gt; Tekan Enter.&lt;br&gt;&lt;b&gt;Kosongkan perkataan:&lt;/b&gt; Tekan Ctrl+Backspace.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Abjad:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Temui:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n mata</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Permainan mencari perkataan</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Fail permainan untuk main.</translation>
    </message>
</context>
</TS>
